<?php
session_start();
require 'db_con.php'; // Assurez-vous que db_con.php est inclus pour la connexion à la base de données

// Vérifiez si l'utilisateur est connecté
if (!isset($_SESSION['user_id'])) {
    header("Location: index.php");
    exit;
}

// Vérifiez le rôle de l'utilisateur
$role = $_SESSION['role'];
if ($role !== 'admin' && $role !== 'chef') {
    header("Location: main.php");
    exit;
}

// Ajouter un langage
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['add_language'])) {
    $language_name = $_POST['language_name'];
    $stmt = $pdo->prepare("INSERT INTO language (name) VALUES (:name)");
    $stmt->execute(['name' => $language_name]);
}

// Modifier un langage
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['edit_language'])) {
    $language_id = $_POST['language_id'];
    $language_name = $_POST['language_name'];
    $stmt = $pdo->prepare("UPDATE language SET name = :name WHERE id = :id");
    $stmt->execute(['name' => $language_name, 'id' => $language_id]);
}

// Supprimer un langage
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['delete_language'])) {
    $language_id = $_POST['language_id'];
    $stmt = $pdo->prepare("DELETE FROM language WHERE id = :id");
    $stmt->execute(['id' => $language_id]);
}

// Récupérer tous les langages
$stmt = $pdo->query("SELECT * FROM language");
$languages = $stmt->fetchAll();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Manage Languages</title>
</head>
<body>
    <h1>Manage Programming Languages</h1>

    <!-- Formulaire pour ajouter un langage -->
    <h2>Add Language</h2>
    <form method="POST">
        <input type="text" name="language_name" required placeholder="Language Name">
        <button type="submit" name="add_language">Add</button>
    </form>

    <h2>Existing Languages</h2>
    <table>
        <tr>
            <th>ID</th>
            <th>Name</th>
            <th>Actions</th>
        </tr>
        <?php foreach ($languages as $language): ?>
            <tr>
                <td><?php echo htmlspecialchars($language['id']); ?></td>
                <td><?php echo htmlspecialchars($language['name']); ?></td>
                <td>
                    <!-- Formulaire pour modifier un langage -->
                    <form method="POST" style="display:inline;">
                        <input type="hidden" name="language_id" value="<?php echo $language['id']; ?>">
                        <input type="text" name="language_name" value="<?php echo htmlspecialchars($language['name']); ?>" required>
                        <button type="submit" name="edit_language">Edit</button>
                    </form>
                    <!-- Formulaire pour supprimer un langage -->
                    <form method="POST" style="display:inline;">
                        <input type="hidden" name="language_id" value="<?php echo $language['id']; ?>">
                        <button type="submit" name="delete_language" onclick="return confirm('Are you sure you want to delete this language?');">Delete</button>
                    </form>
                </td>
            </tr>
        <?php endforeach; ?>
    </table>
    <a href="main.php">Retour à la page principale</a>
</body>
</html>
